summaryrefslogtreecommitdiffstats
path: root/konq-plugins/validators/plugin_validators.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit90363652674deb94cd07057428b24fcb1735dbce (patch)
tree35013223cb731f194f8584cc1c06a023c3c75c85 /konq-plugins/validators/plugin_validators.cpp
parent627b091fad9df13695f249588e8a58f524eda0fa (diff)
downloadtdeaddons-90363652674deb94cd07057428b24fcb1735dbce.tar.gz
tdeaddons-90363652674deb94cd07057428b24fcb1735dbce.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaddons@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konq-plugins/validators/plugin_validators.cpp')
-rw-r--r--konq-plugins/validators/plugin_validators.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/konq-plugins/validators/plugin_validators.cpp b/konq-plugins/validators/plugin_validators.cpp
index 6bd4fee..fe61ae3 100644
--- a/konq-plugins/validators/plugin_validators.cpp
+++ b/konq-plugins/validators/plugin_validators.cpp
@@ -44,9 +44,9 @@ static const KAboutData aboutdata("validatorsplugin", I18N_NOOP("Validate Web Pa
K_EXPORT_COMPONENT_FACTORY( libvalidatorsplugin,
PluginValidatorsFactory( &aboutdata ) )
-PluginValidators::PluginValidators( TQObject* tqparent, const char* name,
+PluginValidators::PluginValidators( TQObject* parent, const char* name,
const TQStringList & )
- : Plugin( tqparent, name ), m_configDialog(0), m_part(0)
+ : Plugin( parent, name ), m_configDialog(0), m_part(0)
{
setInstance(PluginValidatorsFactory::instance());
@@ -71,14 +71,14 @@ PluginValidators::PluginValidators( TQObject* tqparent, const char* name,
m_menu->setEnabled( false );
- if ( tqparent && tqparent->inherits( "KHTMLPart" ))
+ if ( parent && parent->inherits( "KHTMLPart" ))
{
m_menu->insert( new KAction( i18n( "C&onfigure Validator..." ),
"configure", 0,
this, TQT_SLOT(slotConfigure()),
actionCollection(), "configure") );
- m_part = static_cast<KHTMLPart *>( tqparent );
+ m_part = static_cast<KHTMLPart *>( parent );
m_configDialog = new ValidatorsDialog( m_part->widget() );
setURLs();
@@ -90,7 +90,7 @@ PluginValidators::PluginValidators( TQObject* tqparent, const char* name,
PluginValidators::~PluginValidators()
{
delete m_configDialog;
// Dont' delete the action. KActionCollection as tqparent does the job already
// and not deleting it at this point also ensures that in case we are not unplugged
// from the GUI yet and the ~KXMLGUIClient destructor will do so it won't hit a
// dead pointer. The kxmlgui factory keeps references to the actions, but it does not
@@ -140,8 +140,8 @@ void PluginValidators::slotConfigure()
void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
{
- // The tqparent is assumed to be a KHTMLPart
- if ( !tqparent()->inherits("KHTMLPart") )
+ // The parent is assumed to be a KHTMLPart
+ if ( !parent()->inherits("KHTMLPart") )
{
TQString title = i18n( "Cannot Validate Source" );
TQString text = i18n( "You cannot validate anything except web pages with "
@@ -90,7 +90,7 @@ PluginValidators::PluginValidators( TQObject* tqparent, const char* name,
{
delete m_configDialog;
-// Dont' delete the action. KActionCollection as tqparent does the job already
+// Dont' delete the action. KActionCollection as parent does the job already
// and not deleting it at this point also ensures that in case we are not unplugged
// from the GUI yet and the ~KXMLGUIClient destructor will do so it won't hit a